import { ITHit } from "webdav.client";
import { UrlResolveService } from "../services/urlResolveService";
import { UploaderHandlers } from "./uploaderHandlers";

export class Uploader {
  private uploader: ITHit.WebDAV.Client.Upload.Uploader;
  private isDropzoneAdded = false;
  private handlers: UploaderHandlers;


  public constructor(url: string, handlers: UploaderHandlers) {
    this.uploader = new ITHit.WebDAV.Client.Upload.Uploader();
    this.setUploadUrl(url);
    this.handlers = handlers;
    this.uploader.Queue.AddListener("OnQueueChanged", handlers.onQueueChanged, this);
    this.uploader.Queue.AddListener("OnUploadItemsCreated", handlers.onUploadItemsCreated, this);
  }

  public destroy() {
    if (this.uploader !== null) {
      this.uploader.Queue.RemoveListener("OnQueueChanged", this.handlers.onQueueChanged, this);
      this.uploader.Queue.RemoveListener("OnUploadItemsCreated", this.handlers.onUploadItemsCreated, this);
    }
  }

  public setUploadUrl(url: string) {
    this.uploader?.SetUploadUrl(UrlResolveService.decode(url));
  }

  public addDropzone() {
    if (!this.isDropzoneAdded) {
      this.uploader.Inputs.AddById("ithit-hidden-input");
      this.uploader.DropZones.AddById("ithit-dropzone");
      this.isDropzoneAdded = true;
    }
  }

  public addInput(inputId: string) {
    this.uploader.Inputs.AddById(inputId);
  }
}
