import { defineStore } from "pinia";
import { RewriteItemsData } from "../models/rewriteItemsData";
import { UploadItemRow } from "../models/uploadItemRow";
import { ITHit } from "webdav.client";
import { Uploader } from "../models/uploader";



export interface UploadState {
  uploadItemRows: UploadItemRow[];
  rewriteItemsData: RewriteItemsData | null;
  isDragging: boolean;
  uploader: Uploader | null;
}
export const initialState: UploadState = {
  uploadItemRows: [],
  rewriteItemsData: null,
  isDragging: false,
  uploader: null
}

export const useUploadStore = defineStore('upload', {
  state: (): UploadState => (initialState),
  getters: {

  },
  actions: {
    addUploadItemRow(uploadItemRow: UploadItemRow) {
      this.uploadItemRows.push(uploadItemRow);
    },
    removeUploadItemRow(uploadItem: ITHit.WebDAV.Client.Upload.UploadItem) {
      this.uploadItemRows = this.uploadItemRows.filter((item) => {
        if (item.uploadItem === uploadItem) {
          item.destroy();
        }
        return item.uploadItem !== uploadItem;
      });
    },
    setRewriteItemsData(rewriteItemsData: RewriteItemsData | null) {
      this.rewriteItemsData = rewriteItemsData;
    },
    setIsDragging(isDragging: boolean) {
      this.isDragging = isDragging;
    },
    setUploader(uploader: Uploader) {
      this.uploader = uploader;
    }
  }
});